@@ -42,6 +42,8 @@ class WeConnectSession(VWWebSession):
             'x-newrelic-id': 'VgAEWV9QDRAEXFlRAAYPUA==',
             'user-agent': 'WeConnect/3 CFNetwork/1331.0.7 Darwin/21.4.0',
             'accept-language': 'de-de',
+            'Cache-Control': 'no-cache',
+            'Pragma': 'no-cache'
         })
 
     def request(
@@ -105,6 +107,7 @@ class WeConnectSession(VWWebSession):
                         backoff_factor=0.1,
                         status_forcelist=[500],
                         raise_on_status=False)
+        websession.proxies.update(self.proxies)
         websession.mount('https://', HTTPAdapter(max_retries=retries))
         websession.headers = CaseInsensitiveDict({
             'user-agent': 'Mozilla/5.0 (Linux; Android 10) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 '
