@@ -3,11 +3,14 @@ from enum import Enum
 
 class Domain(Enum):
     ALL = 'all'
+    ALL_CAPABLE = 'allCapable'
     ACCESS = 'access'
     AUTOMATION = 'automation'
     USER_CAPABILITIES = 'userCapabilities'
     CHARGING = 'charging'
+    CHARGING_PROFILES = 'chargingProfiles'
     CLIMATISATION = 'climatisation'
+    DEPARTURE_TIMERS = 'departureTimers'
     FUEL_STATUS = 'fuelStatus'
     VEHICLE_LIGHTS = 'vehicleLights'
     LV_BATTERY = 'lvBattery'
