@@ -25,7 +25,12 @@ class OdometerMeasurement(GenericStatus):
 
         if 'value' in fromDict:
             if 'odometer' in fromDict['value']:
-                self.odometer.setValueWithCarTime(int(fromDict['value']['odometer']), lastUpdateFromCar=None, fromServer=True)
+                odometer = int(fromDict['value']['odometer'])
+                if self.fixAPI and odometer == 0x7FFFFFFF:
+                    odometer = None
+                    LOG.info('%s: Attribute odometer was error value 0x7FFFFFFF. Setting error state instead'
+                             ' of 2147483647 km.', self.getGlobalAddress())
+                self.odometer.setValueWithCarTime(odometer, lastUpdateFromCar=None, fromServer=True)
             else:
                 self.odometer.enabled = False
         else:
